@@ -27,11 +27,8 @@ include("lib/nxpt.class.php");
 include("./config.php");
 
 $boardName = array();
-$boardSupportsCookies = array();
-reset($boards);
-while (list($key, $value) = each($boards)) {
-	array_push($boardName, $key);
-	array_push($boardSupportsCookies, count($value->cookies) > 0);
+foreach ($boards as $board => $plop) {
+	array_push($boardName, $board);
 }
 
 wmlHeader();
@@ -39,7 +36,6 @@ wmlHeader();
 $nxpt = new nxpt;
 $nxpt->nxpt_cache_path("cache");
 $nxpt->assign("boardName", $boardName);
-$nxpt->assign("boardSupportsCookies", $boardSupportsCookies);
 $nxpt->display("template/index.xml");
 
 ?>
